import { useCallback, useEffect, useState } from 'react';

import * as fs from 'fs';

export function usePromise<T>(f: () => Promise<T>): T | null {
	const [value, setValue] = useState<T | null>(null);

	useEffect(() => {
		setValue(null);

		let cancelled = false;

		(async (): Promise<void> => {
			const v = await f();
			if (!cancelled) {
				setValue(v);
			}
		})();

		return (): void => {
			cancelled = true;
		};
	}, [f]);

	return value;
}

export function useReadFile(path: string): Buffer | null {
	const readFile = useCallback(() => fs.promises.readFile(path), [path]);
	return usePromise(readFile);
}

export async function readJSON(path: string): Promise<unknown> {
	const content = await fs.promises.readFile(path, 'utf8');
	return JSON.parse(content);
}
